@@ -16,7 +16,6 @@ Options:
     --gen_pdf=<mail_id>     Generate pdf of contained email id.
     --stats                 Get email stats following stats
 """
-
 from datetime import datetime
 from datetime import timedelta
 from docopt import docopt
@@ -35,6 +34,7 @@ import imaplib
 import json
 import logging
 import os
+import re
 import requests
 import six
 import sys
@@ -101,6 +101,17 @@ Si vous utilisez Mozilla Thunderbird:\n
 Cordialement.\n
 """
 
+IGNORED_MAIL = u"""
+Bonjour,
+Votre adresse email {3} n'est pas autorisée à transférer un email vers iA.docs.
+Si cette action est justifiée, veuillez prendre contact avec votre référent interne.\n
+Le mail concerné est en pièce jointe.\n
+Client ID : {0}
+IMAP login : {1}
+mail id : {2}
+pattern : "{4}"
+"""
+
 RESULT_MAIL = u"""
 Client ID : {0}
 IMAP login : {1}\n
@@ -174,6 +185,34 @@ def notify_unsupported_origin(config, mail, from_):
     smtp.quit()
 
 
+def notify_ignored(config, mail_id, mail, from_):
+    client_id = config["webservice"]["client_id"]
+    login = config["mailbox"]["login"]
+    smtp_infos = config["smtp"]
+    sender = smtp_infos["sender"]
+    recipient = smtp_infos["recipient"]
+
+    msg = MIMEMultipart()
+    msg["Subject"] = "Transfert non autorisé de {} pour le client {}".format(from_, client_id)
+    msg["From"] = sender
+    msg["To"] = from_
+    msg["Bcc"] = recipient
+
+    main_text = MIMEText(IGNORED_MAIL.format(client_id, login, mail_id, from_, config['mailinfos']['sender-pattern']),
+                         "plain")
+    msg.attach(main_text)
+
+    attachment = MIMEBase("message", "rfc822")
+    attachment.set_payload(mail.as_string())
+    attachment.add_header("Content-Disposition", "inline")
+    msg.attach(attachment)
+
+    smtp = SMTP(str(smtp_infos["host"]), int(smtp_infos["port"]))
+    msg_content = msg.as_string().encode("utf8") if six.PY3 else msg.as_string()
+    smtp.sendmail(sender, recipient, msg_content)
+    smtp.quit()
+
+
 def notify_result(config, subject, message):
     client_id = config["webservice"]["client_id"]
     login = config["mailbox"]["login"]
@@ -195,6 +234,12 @@ def notify_result(config, subject, message):
     smtp.quit()
 
 
+def check_transferer(sender, pattern):
+    if re.match(pattern, sender, re.I):
+        return True
+    return False
+
+
 def get_mailbox_infos(config):
     mailbox_infos = config["mailbox"]
     host = str(mailbox_infos["host"])
@@ -316,6 +361,7 @@ def process_mails():
         handler.list_last_emails(nb=int(arguments.get("--list_emails")))
         # import ipdb; ipdb.set_trace()
         # handler.mark_reset_error('58')
+        # handler.mark_reset_ignored('77')
         # res, data = handler.connection.search(None, 'SUBJECT "JBC client"')
         # for mail_id in data[0].split():
         #      mail = handler.get_mail(mail_id)
@@ -366,7 +412,7 @@ def process_mails():
         logger.info('Ended at {}'.format(datetime.now()))
         sys.exit()
 
-    imported = errors = unsupported = 0
+    imported = errors = unsupported = ignored = 0
     # import ipdb; ipdb.set_trace()
     for mail_info in handler.get_waiting_emails():
         mail_id = mail_info.id
@@ -381,6 +427,14 @@ def process_mails():
                 unsupported += 1
                 continue
             headers = parser.headers
+            # we check if the pushing agent has a permitted email format
+            if not check_transferer(headers['Agent'][0][1], config['mailinfos'].get('sender-pattern', '.+')):
+                handler.mark_mail_as_ignored(mail_id)
+                notify_ignored(config, mail_id, mail, headers['Agent'][0][1])
+                # logger.error('Rejecting {}: {}'.format(headers['Agent'][0][1], headers['Subject']))
+                ignored += 1
+                continue
+            # logger.info('Accepting {}: {}'.format(headers['Agent'][0][1], headers['Subject']))
             attachments = parser.attachments
             try:
                 parser.generate_pdf(main_file_path)
@@ -397,11 +451,8 @@ def process_mails():
             handler.mark_mail_as_error(mail_id)
             errors += 1
 
-    logger.info(
-        "{} emails have been imported. {} emails are unsupported. {} emails have caused an error.".format(
-            imported, unsupported, errors
-        )
-    )
+    logger.info("{} emails have been imported. {} emails are unsupported. {} emails have caused an error. {} emails "
+                "are ignored".format(imported, unsupported, errors, ignored))
     handler.disconnect()
     lock.close()
 
